<?php
/**
 * Tests the SchoolNames code
 *
 * This work is licensed under the MIT License
 * Copyright (c) 2011 Bairwell Ltd
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * PHP Version 5
 *
 * @package Bairwell
 * @subpackage NameAlternatives
 * @author Richard Chiswell <richard@bairwell.com>
 * @copyright 2011 Bairwell Ltd
 * @license MIT
 */
namespace Bairwell\NameAlternatives\Tests\GB;

/**
 * Test class for School Names titles
 */
class SchoolNamesTest extends \Bairwell\NameAlternatives\Tests\Base
{
    /**
     * The list of names we are looking to compare against
     * @var array
     */
    protected $names = Array(
        'abc'
    );

    public function testParse_Unittest()
    {
        $this->runOverviewTest('\Bairwell\NameAlternatives\GB\SchoolNames');
    }


    public function testParse_Functional()
    {
        /**
         * @var \Bairwell\NameAlternatives\GB\PlaceNames $object
         */
        $object = \Bairwell\DI::getLibrary('\Bairwell\NameAlternatives\GB\SchoolNames');
        $results = $object->parse('LEICESTER COE PERFORMING ARTS SCHOOL');
        $expectedChanges = Array(
            'LEICESTER COE PERFORMING ARTS SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTER COE SCHOOL',
            'LEICESTER COE PERFORMING ARTS',
            'LEICESTER COE',
            'LEICESTER PERFORMING ARTS SCHOOL',
            'LEICESTER CHURCH OF ENGLAND SCHOOL',
            'LEICESTER SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERFORMING ARTS',
            'LEICESTER PERFORMING ARTS',
            'LEICESTER CHURCH OF ENGLAND',
            'LEICESTER',
            'LEICESTER CHURCH ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTER CHURCH ENGLAND SCHOOL',
            'LEICESTER CHURCH ENGLAND PERFORMING ARTS',
            'LEICESTER CHURCH ENGLAND',
            'LESTER COE PERFORMING ARTS SCHOOL',
            'LEICS COE PERFORMING ARTS SCHOOL',
            'LEICESTERSHIRE COE PERFORMING ARTS SCHOOL',
            'LEIC COE PERFORMING ARTS SCHOOL',
            'LESTER CHURCH OF ENGLAND PERFORMING ARTS SCHOOL',
            'LEICS CHURCH OF ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERFORMING ARTS SCHOOL',
            'LEIC CHURCH OF ENGLAND PERFORMING ARTS SCHOOL',
            'LESTER COE SCHOOL',
            'LEICS COE SCHOOL',
            'LEICESTERSHIRE COE SCHOOL',
            'LEIC COE SCHOOL',
            'LESTER COE PERFORMING ARTS',
            'LEICS COE PERFORMING ARTS',
            'LEICESTERSHIRE COE PERFORMING ARTS',
            'LEIC COE PERFORMING ARTS',
            'LESTER COE',
            'LEICS COE',
            'LEICESTERSHIRE COE',
            'LEIC COE',
            'LESTER PERFORMING ARTS SCHOOL',
            'LEICS PERFORMING ARTS SCHOOL',
            'LEICESTERSHIRE PERFORMING ARTS SCHOOL',
            'LEIC PERFORMING ARTS SCHOOL',
            'LESTER CHURCH OF ENGLAND SCHOOL',
            'LEICS CHURCH OF ENGLAND SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND SCHOOL',
            'LEIC CHURCH OF ENGLAND SCHOOL',
            'LESTER SCHOOL',
            'LEICS SCHOOL',
            'LEICESTERSHIRE SCHOOL',
            'LEIC SCHOOL',
            'LESTER CHURCH OF ENGLAND PERFORMING ARTS',
            'LEICS CHURCH OF ENGLAND PERFORMING ARTS',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERFORMING ARTS',
            'LEIC CHURCH OF ENGLAND PERFORMING ARTS',
            'LESTER PERFORMING ARTS',
            'LEICS PERFORMING ARTS',
            'LEICESTERSHIRE PERFORMING ARTS',
            'LEIC PERFORMING ARTS',
            'LESTER CHURCH OF ENGLAND',
            'LEICS CHURCH OF ENGLAND',
            'LEICESTERSHIRE CHURCH OF ENGLAND',
            'LEIC CHURCH OF ENGLAND',
            'LESTER',
            'LEICS',
            'LEICESTERSHIRE',
            'LEIC',
            'LESTER CHURCH ENGLAND PERFORMING ARTS SCHOOL',
            'LEICS CHURCH ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND PERFORMING ARTS SCHOOL',
            'LEIC CHURCH ENGLAND PERFORMING ARTS SCHOOL',
            'LESTER CHURCH ENGLAND SCHOOL',
            'LEICS CHURCH ENGLAND SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND SCHOOL',
            'LEIC CHURCH ENGLAND SCHOOL',
            'LESTER CHURCH ENGLAND PERFORMING ARTS',
            'LEICS CHURCH ENGLAND PERFORMING ARTS',
            'LEICESTERSHIRE CHURCH ENGLAND PERFORMING ARTS',
            'LEIC CHURCH ENGLAND PERFORMING ARTS',
            'LESTER CHURCH ENGLAND',
            'LEICS CHURCH ENGLAND',
            'LEICESTERSHIRE CHURCH ENGLAND',
            'LEIC CHURCH ENGLAND',
            'LEICESTER COE PERPHORMING ARTS SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTER COE PERPHORMING ARTS',
            'LEICESTER PERPHORMING ARTS SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERFORMING ARTS',
            'LEICESTER CHURCH OF ENGLAND PERPHORMING ARTS',
            'LEICESTER CHURCH OPH ENGLAND PERPHORMING ARTS',
            'LEICESTER PERPHORMING ARTS',
            'LEICESTER CHURCH OPH ENGLAND',
            'LEICESTER CHURCH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTER CHURCH ENGLAND PERPHORMING ARTS',
            'LESTER COE PERPHORMING ARTS SCHOOL',
            'LEICS COE PERPHORMING ARTS SCHOOL',
            'LEICESTERSHIRE COE PERPHORMING ARTS SCHOOL',
            'LEIC COE PERPHORMING ARTS SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERFORMING ARTS SCHOOL',
            'LESTER CHURCH OF ENGLAND PERPHORMING ARTS SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICS CHURCH OPH ENGLAND PERFORMING ARTS SCHOOL',
            'LEICS CHURCH OF ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICS CHURCH OPH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEIC CHURCH OPH ENGLAND PERFORMING ARTS SCHOOL',
            'LEIC CHURCH OF ENGLAND PERPHORMING ARTS SCHOOL',
            'LEIC CHURCH OPH ENGLAND PERPHORMING ARTS SCHOOL',
            'LESTER COE PERPHORMING ARTS',
            'LEICS COE PERPHORMING ARTS',
            'LEICESTERSHIRE COE PERPHORMING ARTS',
            'LEIC COE PERPHORMING ARTS',
            'LESTER PERPHORMING ARTS SCHOOL',
            'LEICS PERPHORMING ARTS SCHOOL',
            'LEICESTERSHIRE PERPHORMING ARTS SCHOOL',
            'LEIC PERPHORMING ARTS SCHOOL',
            'LESTER CHURCH OPH ENGLAND SCHOOL',
            'LEICS CHURCH OPH ENGLAND SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND SCHOOL',
            'LEIC CHURCH OPH ENGLAND SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERFORMING ARTS',
            'LESTER CHURCH OF ENGLAND PERPHORMING ARTS',
            'LESTER CHURCH OPH ENGLAND PERPHORMING ARTS',
            'LEICS CHURCH OPH ENGLAND PERFORMING ARTS',
            'LEICS CHURCH OF ENGLAND PERPHORMING ARTS',
            'LEICS CHURCH OPH ENGLAND PERPHORMING ARTS',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERFORMING ARTS',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERPHORMING ARTS',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERPHORMING ARTS',
            'LEIC CHURCH OPH ENGLAND PERFORMING ARTS',
            'LEIC CHURCH OF ENGLAND PERPHORMING ARTS',
            'LEIC CHURCH OPH ENGLAND PERPHORMING ARTS',
            'LESTER PERPHORMING ARTS',
            'LEICS PERPHORMING ARTS',
            'LEICESTERSHIRE PERPHORMING ARTS',
            'LEIC PERPHORMING ARTS',
            'LESTER CHURCH OPH ENGLAND',
            'LEICS CHURCH OPH ENGLAND',
            'LEICESTERSHIRE CHURCH OPH ENGLAND',
            'LEIC CHURCH OPH ENGLAND',
            'LESTER CHURCH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICS CHURCH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND PERPHORMING ARTS SCHOOL',
            'LEIC CHURCH ENGLAND PERPHORMING ARTS SCHOOL',
            'LESTER CHURCH ENGLAND PERPHORMING ARTS',
            'LEICS CHURCH ENGLAND PERPHORMING ARTS',
            'LEICESTERSHIRE CHURCH ENGLAND PERPHORMING ARTS',
            'LEIC CHURCH ENGLAND PERPHORMING ARTS',
            'LEICESTER COE PERVORMING ARTS SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTER COE PERVORMING ARTS',
            'LEICESTER PERVORMING ARTS SCHOOL',
            'LEICESTER CHURCH OV ENGLAND SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERFORMING ARTS',
            'LEICESTER CHURCH OF ENGLAND PERVORMING ARTS',
            'LEICESTER CHURCH OV ENGLAND PERPHORMING ARTS',
            'LEICESTER CHURCH OPH ENGLAND PERVORMING ARTS',
            'LEICESTER CHURCH OV ENGLAND PERVORMING ARTS',
            'LEICESTER PERVORMING ARTS',
            'LEICESTER CHURCH OV ENGLAND',
            'LEICESTER CHURCH ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTER CHURCH ENGLAND PERVORMING ARTS',
            'LESTER COE PERVORMING ARTS SCHOOL',
            'LEICS COE PERVORMING ARTS SCHOOL',
            'LEICESTERSHIRE COE PERVORMING ARTS SCHOOL',
            'LEIC COE PERVORMING ARTS SCHOOL',
            'LESTER CHURCH OV ENGLAND PERFORMING ARTS SCHOOL',
            'LESTER CHURCH OF ENGLAND PERVORMING ARTS SCHOOL',
            'LESTER CHURCH OV ENGLAND PERPHORMING ARTS SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERVORMING ARTS SCHOOL',
            'LESTER CHURCH OV ENGLAND PERVORMING ARTS SCHOOL',
            'LEICS CHURCH OV ENGLAND PERFORMING ARTS SCHOOL',
            'LEICS CHURCH OF ENGLAND PERVORMING ARTS SCHOOL',
            'LEICS CHURCH OV ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICS CHURCH OPH ENGLAND PERVORMING ARTS SCHOOL',
            'LEICS CHURCH OV ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERFORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERPHORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERVORMING ARTS SCHOOL',
            'LEIC CHURCH OV ENGLAND PERFORMING ARTS SCHOOL',
            'LEIC CHURCH OF ENGLAND PERVORMING ARTS SCHOOL',
            'LEIC CHURCH OV ENGLAND PERPHORMING ARTS SCHOOL',
            'LEIC CHURCH OPH ENGLAND PERVORMING ARTS SCHOOL',
            'LEIC CHURCH OV ENGLAND PERVORMING ARTS SCHOOL',
            'LESTER COE PERVORMING ARTS',
            'LEICS COE PERVORMING ARTS',
            'LEICESTERSHIRE COE PERVORMING ARTS',
            'LEIC COE PERVORMING ARTS',
            'LESTER PERVORMING ARTS SCHOOL',
            'LEICS PERVORMING ARTS SCHOOL',
            'LEICESTERSHIRE PERVORMING ARTS SCHOOL',
            'LEIC PERVORMING ARTS SCHOOL',
            'LESTER CHURCH OV ENGLAND SCHOOL',
            'LEICS CHURCH OV ENGLAND SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND SCHOOL',
            'LEIC CHURCH OV ENGLAND SCHOOL',
            'LESTER CHURCH OV ENGLAND PERFORMING ARTS',
            'LESTER CHURCH OF ENGLAND PERVORMING ARTS',
            'LESTER CHURCH OV ENGLAND PERPHORMING ARTS',
            'LESTER CHURCH OPH ENGLAND PERVORMING ARTS',
            'LESTER CHURCH OV ENGLAND PERVORMING ARTS',
            'LEICS CHURCH OV ENGLAND PERFORMING ARTS',
            'LEICS CHURCH OF ENGLAND PERVORMING ARTS',
            'LEICS CHURCH OV ENGLAND PERPHORMING ARTS',
            'LEICS CHURCH OPH ENGLAND PERVORMING ARTS',
            'LEICS CHURCH OV ENGLAND PERVORMING ARTS',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERFORMING ARTS',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERVORMING ARTS',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERPHORMING ARTS',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERVORMING ARTS',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERVORMING ARTS',
            'LEIC CHURCH OV ENGLAND PERFORMING ARTS',
            'LEIC CHURCH OF ENGLAND PERVORMING ARTS',
            'LEIC CHURCH OV ENGLAND PERPHORMING ARTS',
            'LEIC CHURCH OPH ENGLAND PERVORMING ARTS',
            'LEIC CHURCH OV ENGLAND PERVORMING ARTS',
            'LESTER PERVORMING ARTS',
            'LEICS PERVORMING ARTS',
            'LEICESTERSHIRE PERVORMING ARTS',
            'LEIC PERVORMING ARTS',
            'LESTER CHURCH OV ENGLAND',
            'LEICS CHURCH OV ENGLAND',
            'LEICESTERSHIRE CHURCH OV ENGLAND',
            'LEIC CHURCH OV ENGLAND',
            'LESTER CHURCH ENGLAND PERVORMING ARTS SCHOOL',
            'LEICS CHURCH ENGLAND PERVORMING ARTS SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND PERVORMING ARTS SCHOOL',
            'LEIC CHURCH ENGLAND PERVORMING ARTS SCHOOL',
            'LESTER CHURCH ENGLAND PERVORMING ARTS',
            'LEICS CHURCH ENGLAND PERVORMING ARTS',
            'LEICESTERSHIRE CHURCH ENGLAND PERVORMING ARTS',
            'LEIC CHURCH ENGLAND PERVORMING ARTS',
            'LEICESTER COE PERFORMING ART SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERFORMING ART SCHOOL',
            'LEICESTER COE PERFORMING ART',
            'LEICESTER PERFORMING ART SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERFORMING ART',
            'LEICESTER PERFORMING ART',
            'LEICESTER CHURCH ENGLAND PERFORMING ART SCHOOL',
            'LEICESTER CHURCH ENGLAND PERFORMING ART',
            'LESTER COE PERFORMING ART SCHOOL',
            'LEIC COE PERFORMING ART SCHOOL',
            'LEICESTERSHIRE COE PERFORMING ART SCHOOL',
            'LESTER CHURCH OF ENGLAND PERFORMING ART SCHOOL',
            'LEIC CHURCH OF ENGLAND PERFORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERFORMING ART SCHOOL',
            'LESTER COE PERFORMING ART',
            'LEIC COE PERFORMING ART',
            'LEICESTERSHIRE COE PERFORMING ART',
            'LESTER PERFORMING ART SCHOOL',
            'LEIC PERFORMING ART SCHOOL',
            'LEICESTERSHIRE PERFORMING ART SCHOOL',
            'LESTER CHURCH OF ENGLAND PERFORMING ART',
            'LEIC CHURCH OF ENGLAND PERFORMING ART',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERFORMING ART',
            'LESTER PERFORMING ART',
            'LEIC PERFORMING ART',
            'LEICESTERSHIRE PERFORMING ART',
            'LESTER CHURCH ENGLAND PERFORMING ART SCHOOL',
            'LEIC CHURCH ENGLAND PERFORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND PERFORMING ART SCHOOL',
            'LESTER CHURCH ENGLAND PERFORMING ART',
            'LEIC CHURCH ENGLAND PERFORMING ART',
            'LEICESTERSHIRE CHURCH ENGLAND PERFORMING ART',
            'LEICESTER COE PERPHORMING ART SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERFORMING ART SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTER COE PERPHORMING ART',
            'LEICESTER PERPHORMING ART SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERFORMING ART',
            'LEICESTER CHURCH OF ENGLAND PERPHORMING ART',
            'LEICESTER CHURCH OPH ENGLAND PERPHORMING ART',
            'LEICESTER PERPHORMING ART',
            'LEICESTER CHURCH ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTER CHURCH ENGLAND PERPHORMING ART',
            'LESTER COE PERPHORMING ART SCHOOL',
            'LEIC COE PERPHORMING ART SCHOOL',
            'LEICESTERSHIRE COE PERPHORMING ART SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERFORMING ART SCHOOL',
            'LESTER CHURCH OF ENGLAND PERPHORMING ART SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERPHORMING ART SCHOOL',
            'LEIC CHURCH OPH ENGLAND PERFORMING ART SCHOOL',
            'LEIC CHURCH OF ENGLAND PERPHORMING ART SCHOOL',
            'LEIC CHURCH OPH ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERFORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERPHORMING ART SCHOOL',
            'LESTER COE PERPHORMING ART',
            'LEIC COE PERPHORMING ART',
            'LEICESTERSHIRE COE PERPHORMING ART',
            'LESTER PERPHORMING ART SCHOOL',
            'LEIC PERPHORMING ART SCHOOL',
            'LEICESTERSHIRE PERPHORMING ART SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERFORMING ART',
            'LESTER CHURCH OF ENGLAND PERPHORMING ART',
            'LESTER CHURCH OPH ENGLAND PERPHORMING ART',
            'LEIC CHURCH OPH ENGLAND PERFORMING ART',
            'LEIC CHURCH OF ENGLAND PERPHORMING ART',
            'LEIC CHURCH OPH ENGLAND PERPHORMING ART',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERFORMING ART',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERPHORMING ART',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERPHORMING ART',
            'LESTER PERPHORMING ART',
            'LEIC PERPHORMING ART',
            'LEICESTERSHIRE PERPHORMING ART',
            'LESTER CHURCH ENGLAND PERPHORMING ART SCHOOL',
            'LEIC CHURCH ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND PERPHORMING ART SCHOOL',
            'LESTER CHURCH ENGLAND PERPHORMING ART',
            'LEIC CHURCH ENGLAND PERPHORMING ART',
            'LEICESTERSHIRE CHURCH ENGLAND PERPHORMING ART',
            'LEICESTER COE PERVORMING ART SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERFORMING ART SCHOOL',
            'LEICESTER CHURCH OF ENGLAND PERVORMING ART SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTER CHURCH OPH ENGLAND PERVORMING ART SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERVORMING ART SCHOOL',
            'LEICESTER COE PERVORMING ART',
            'LEICESTER PERVORMING ART SCHOOL',
            'LEICESTER CHURCH OV ENGLAND PERFORMING ART',
            'LEICESTER CHURCH OF ENGLAND PERVORMING ART',
            'LEICESTER CHURCH OV ENGLAND PERPHORMING ART',
            'LEICESTER CHURCH OPH ENGLAND PERVORMING ART',
            'LEICESTER CHURCH OV ENGLAND PERVORMING ART',
            'LEICESTER PERVORMING ART',
            'LEICESTER CHURCH ENGLAND PERVORMING ART SCHOOL',
            'LEICESTER CHURCH ENGLAND PERVORMING ART',
            'LESTER COE PERVORMING ART SCHOOL',
            'LEIC COE PERVORMING ART SCHOOL',
            'LEICESTERSHIRE COE PERVORMING ART SCHOOL',
            'LESTER CHURCH OV ENGLAND PERFORMING ART SCHOOL',
            'LESTER CHURCH OF ENGLAND PERVORMING ART SCHOOL',
            'LESTER CHURCH OV ENGLAND PERPHORMING ART SCHOOL',
            'LESTER CHURCH OPH ENGLAND PERVORMING ART SCHOOL',
            'LESTER CHURCH OV ENGLAND PERVORMING ART SCHOOL',
            'LEIC CHURCH OV ENGLAND PERFORMING ART SCHOOL',
            'LEIC CHURCH OF ENGLAND PERVORMING ART SCHOOL',
            'LEIC CHURCH OV ENGLAND PERPHORMING ART SCHOOL',
            'LEIC CHURCH OPH ENGLAND PERVORMING ART SCHOOL',
            'LEIC CHURCH OV ENGLAND PERVORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERFORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERVORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERPHORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERVORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERVORMING ART SCHOOL',
            'LESTER COE PERVORMING ART',
            'LEIC COE PERVORMING ART',
            'LEICESTERSHIRE COE PERVORMING ART',
            'LESTER PERVORMING ART SCHOOL',
            'LEIC PERVORMING ART SCHOOL',
            'LEICESTERSHIRE PERVORMING ART SCHOOL',
            'LESTER CHURCH OV ENGLAND PERFORMING ART',
            'LESTER CHURCH OF ENGLAND PERVORMING ART',
            'LESTER CHURCH OV ENGLAND PERPHORMING ART',
            'LESTER CHURCH OPH ENGLAND PERVORMING ART',
            'LESTER CHURCH OV ENGLAND PERVORMING ART',
            'LEIC CHURCH OV ENGLAND PERFORMING ART',
            'LEIC CHURCH OF ENGLAND PERVORMING ART',
            'LEIC CHURCH OV ENGLAND PERPHORMING ART',
            'LEIC CHURCH OPH ENGLAND PERVORMING ART',
            'LEIC CHURCH OV ENGLAND PERVORMING ART',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERFORMING ART',
            'LEICESTERSHIRE CHURCH OF ENGLAND PERVORMING ART',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERPHORMING ART',
            'LEICESTERSHIRE CHURCH OPH ENGLAND PERVORMING ART',
            'LEICESTERSHIRE CHURCH OV ENGLAND PERVORMING ART',
            'LESTER PERVORMING ART',
            'LEIC PERVORMING ART',
            'LEICESTERSHIRE PERVORMING ART',
            'LESTER CHURCH ENGLAND PERVORMING ART SCHOOL',
            'LEIC CHURCH ENGLAND PERVORMING ART SCHOOL',
            'LEICESTERSHIRE CHURCH ENGLAND PERVORMING ART SCHOOL',
            'LESTER CHURCH ENGLAND PERVORMING ART',
            'LEIC CHURCH ENGLAND PERVORMING ART',
            'LEICESTERSHIRE CHURCH ENGLAND PERVORMING ART'
        );
        $this->assertTrue(is_array($results));
        $this->assertEquals(count($results), count($expectedChanges));
        $this->assertEmpty(array_diff($results, $expectedChanges));
    }
}